@@ -101,7 +101,7 @@ class DataAccess:
             # print(df_meta)
             df_meta = df_meta.set_index('paramName').transpose()
             if 'm' in df_meta.columns and 'c' in df_meta.columns:
-                m = int(df_meta.iloc[0]['m'])
+                m = float(df_meta.iloc[0]['m'])
                 c = int(df_meta.iloc[0]['c'])
                 # print(m, type(c))
                 # print(df[str(value2)])
@@ -270,7 +270,7 @@ class DataAccess:
                     df = DataAccess.get_cleaned_table(self, df)
             else:
                 df = df_raw
-                return df
+            return df
 
         except Exception as e:
             print(e)
